#  --------------------------------------------------------------------------
#  file: "Plugins/!!_sketchup_rb_fix_ext.rb" *
#
#  * This file can be renamed to adjust it's load order.
#{
# --------------------------------------------------------------------------
#  Copyright 2005-2012, Google, Inc.
#  --------------------------------------------------------------------------
#
#  The "Tools/sketchup.rb" file defines a number of useful utilities
#     that are used by other Ruby scripts.
#
#  THIS file "Plugins/!!_sketchup_rb_fix_ext.rb", allows loading patches
#    that will fix various issues in the "Tools/sketchup.rb" file.
#
#  --------------------------------------------------------------------------
#  Permission to use, copy, modify, and distribute this software for 
#  any purpose and without fee is hereby granted, provided that the above
#  copyright notice appear in all copies.
#  --------------------------------------------------------------------------
#  THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
#  IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
#  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#  --------------------------------------------------------------------------
#  Versions:
#
#   1.0.0  :  2012-03-02    Dan Rathbun - Palm Bay, FL, USA
#   |
#   ~ First beta release.
#   + Global Platform Constants.
#   ~ Patches to the following:
#       (1) add_separator_to_menu() method
#       (2) inputbox() method
#       (3) require_all() method
#
#   1.1.0  :  2012-03-03    Dan Rathbun - Palm Bay, FL, USA
#   |
#   + Added: require('extensions.rb') to start of file.
#}
#  --------------------------------------------------------------------------
#
#    SketchupExtension registration script.
#
#  ===========================================================================

  # First, we must load the 'sketchup.rb' file from the "Tools" folder:

  require('sketchup.rb')
  require('extensions.rb')

#  ===========================================================================

  # Then we can load patches to fix things that 'sketchup.rb' defines:

 #  ---------------------------------------------------------------------------

  title = "Patch: 'sketchup.rb' add constants"
  fpath = "_patches/sketchup_rb/sketchup_rb_add_constants.rb"
  #
  patch = SketchupExtension.new(title,fpath)
  #
  patch.version     = '1.0.0'
  patch.copyright   = '(c) 2005-2012, Google, Inc., Mountain View, CA, USA'
  #patch.creator     = 'Dan Rathbun - Palm Bay, FL, USA'
  patch.creator     = 'SketchUcation.com Ruby Developers'
  #
  patch.description = 'This patch adds useful global boolean platform constants MAC, WIN, OSX and PC to the ObjectSpace, so they can be used by all plugin authors. On PC, it also defines a HOME environment variable, if not defined. A HOME variable allows ~ (tilde) path expansion using File.expand_path("~/some/dir/path").'
  #
  Sketchup.register_extension(patch,true)

  #  ---------------------------------------------------------------------------

  title = "Patch: 'sketchup.rb' fix add_separator_to_menu()"
  fpath = "_patches/sketchup_rb/sketchup_rb_fix_add_separator_to_menu.rb"
  #
  patch = SketchupExtension.new(title,fpath)
  #
  patch.version     = '1.0.0'
  patch.copyright   = '(c) 2005-2012, Google, Inc., Mountain View, CA, USA'
  #patch.creator     = 'Dan Rathbun - Palm Bay, FL, USA'
  patch.creator     = 'SketchUcation.com Ruby Developers'
  #
  patch.description = 'This patch allows storing menupath names for submenus. (Handles multiple submenus with the same name.) Extends the use to tracking multiple separators per menu, if desired. Adds method argument validation.'
  #
  Sketchup.register_extension(patch,true)

  #  ---------------------------------------------------------------------------

  title = "Patch: 'sketchup.rb' fix inputbox()"
  fpath = "_patches/sketchup_rb/sketchup_rb_fix_inputbox.rb"
  #
  patch = SketchupExtension.new(title,fpath)
  #
  patch.version     = '1.0.0'
  patch.copyright   = '(c) 2005-2012, Google, Inc., Mountain View, CA, USA'
  #patch.creator     = 'Dan Rathbun - Palm Bay, FL, USA'
  patch.creator     = 'SketchUcation.com Ruby Developers'
  #
  patch.description = 'This patch does more argument list validation, and issues more informative exception messages, than UI.inputbox() does. The inputbox() wrapper did no argument list validation at all; and coding errors would result in a messagebox loop, that required killing Sketchup with the Task Manager.'
  #
  Sketchup.register_extension(patch,true)

  #  ---------------------------------------------------------------------------

  title = "Patch: 'sketchup.rb' fix require_all()"
  fpath = "_patches/sketchup_rb/sketchup_rb_fix_require_all.rb"
  #
  patch = SketchupExtension.new(title,fpath)
  #
  patch.version     = '1.0.0'
  patch.copyright   = '(c) 2005-2012, Google, Inc., Mountain View, CA, USA'
  #patch.creator     = 'Dan Rathbun - Palm Bay, FL, USA'
  patch.creator     = 'SketchUcation.com Ruby Developers'
  #
  patch.description = 'This patch does more validation, checks for directory existence, and if the directory has files to load. The method now explictily returns useful values, depending on what was done. Revised the load exception handling, algorithm so that the load loop can continue loading files, if an error occurs in single file. (It previously exited the loop without loading the rest of the files, if any load errors occured.)'
  #
  Sketchup.register_extension(patch,true)


#  ===========================================================================

  title = fpath = patch = nil


  #{# RUN ONCE
  #
  unless file_loaded?(File.basename(__FILE__))

    file_loaded(File.basename(__FILE__))

  end
  #
  #}#
