#  --------------------------------------------------------------------------
#  file: "_patches/sketchup_rb/sketchup_rb_add_constants.rb"
#{  --------------------------------------------------------------------------
#  Copyright 2005-2012, Google, Inc.
#  --------------------------------------------------------------------------
#
#  The "Tools/sketchup.rb" file defines a number of useful utilities
#     that are used by other Ruby scripts.
#
#  THIS file "_patches/sketchup_rb/sketchup_rb_add_constants.rb",
#    fixes certain issues in the "Tools/sketchup.rb" file by overriding
#    methods, adding constants, etc.
#
#  --------------------------------------------------------------------------
#  Permission to use, copy, modify, and distribute this software for 
#  any purpose and without fee is hereby granted, provided that the above
#  copyright notice appear in all copies.
#  --------------------------------------------------------------------------
#  THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
#  IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
#  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#  --------------------------------------------------------------------------
#  Versions:
#
#   1.0.0  :  2012-03-02    Dan Rathbun - Palm Bay, FL, USA
#   |
#   + Adds global constants that are useful to ALL plugin authors:
#     (1) Boolean Platform constants: MAC, OSX, WIN and PC.
#     (2) Defines a HOME environment variable on PC, if not defined.
#}
#  --------------------------------------------------------------------------

require('sketchup.rb')

#  ===========================================================================


  #  ---------------------------------------------------------------------------
  #  GLOBAL PLATFORM CONSTANTS
  #{ ---------------------------------------------------------------------------
  #
    MAC =( RUBY_PLATFORM =~ /(darwin)/ ? true : false ) unless defined?(MAC)
    WIN =( not MAC ) unless defined?(WIN)
    PC  = WIN unless defined?(PC)
    OSX = MAC unless defined?(OSX)
  #}

  #  ---------------------------------------------------------------------------
  #  GLOBAL USER CONSTANTS, ETC.
  #{ ---------------------------------------------------------------------------
  #
  if WIN
    # Create HOME environment variable if not defined on PC.
    # Allows ~ (tilde) path expansion using File.expand_path("~/some/dir/path").
    ENV['HOME']= ENV['USERPROFILE'] unless ENV['HOME']
  end
  
  #}


#  ===========================================================================


  #{# RUN ONCE
  #
  unless file_loaded?(File.basename(__FILE__))

    file_loaded(File.basename(__FILE__))

  end
  #
  #}#
