#  --------------------------------------------------------------------------
#  file: "_patches/sketchup_rb/sketchup_rb_fix_add_separator_to_menu.rb"
#{  --------------------------------------------------------------------------
#  Copyright 2005-2012, Google, Inc.
#  --------------------------------------------------------------------------
#
#  The "Tools/sketchup.rb" file defines a number of useful utilities
#     that are used by other Ruby scripts.
#
#  THIS file "_patches/sketchup_rb/sketchup_rb_fix_add_separator_to_menu.rb",
#    fixes certain issues in the "Tools/sketchup.rb" file by overriding
#    methods, etc.
#
#  --------------------------------------------------------------------------
#  Permission to use, copy, modify, and distribute this software for 
#  any purpose and without fee is hereby granted, provided that the above
#  copyright notice appear in all copies.
#  --------------------------------------------------------------------------
#  THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
#  IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
#  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#  --------------------------------------------------------------------------
#  Versions:
#
#   1.0.0  :  2012-02-29    Dan Rathbun - Palm Bay, FL, USA
#   |
#   + Add a add_separator_to_menu() function to module UI.
#   ~ Alias global add_separator_to_menu() to UI.add_separator_to_menu()
#}
#  --------------------------------------------------------------------------

require('sketchup.rb')

#  ===========================================================================

  # BACKWARD COMPATIBILITY

  def add_separator_to_menu(menuname, menuobject=nil, *extra)
      UI.add_separator_to_menu(menuname, menuobject, *extra)
  end

#  ===========================================================================

  module UI

    class << self  #{ PROXY CLASS
    
      public

      unless method_defined?(:add_separator_to_menu)
      #  ---------------------------------------------------------------------------
      #{ add_separator_to_menu( menuname, menuobject=nil )
      #  ---------------------------------------------------------------------------
      #{
      #  This function will add a separator to a given menu the first
      #  time it is called.  It is useful for adding a separator before
      #  the first plugin that is added to a given menu.
      #
      #  ---------------------------------------------------------------------------
      #  Array $menu_separator_list is defined in "sketchup.rb" file.
      #
      #  This patch allows storing menupath names for submenus, BUT
      #    you must also supply a reference to the custom submenu.
      #    Use a pathname as you would for a filepath. Example:
      #
      #  add_separator_to_menu( 'Plugins/Wizards/Fencing', my_submenu )
      #
      #  Returns true if separator was added, false if not.
      #
      #  Raises a TypeError exception, if a 2nd argument is supplied,
      #    and is not a Sketchup::Menu instance.
      #
      #  Note: This feature can be used to add and track multiple "section"
      #        separators on a single menu, even a top level menu.
      #        Example:
      #
      #        add_separator_to_menu('Plugins-secondline',UI.menu('Plugins'))
      #}
      def add_separator_to_menu( menuname, menuobject=nil, *extra )
          #
          unless menuname.is_a?(String)
            stack =( caller(0).size < 2 ? caller(0) : caller(1) )
            raise(TypeError,"(1st arg) String object expected.",stack)
          end
          #
          unless menuobject # act normally:
            unless ['Camera','Draw','Edit','File','Help','Plugins','Tools','View','Window'].include?(menuname)
              # raise a exception
              msg = "(1st arg) is not a toplevel Sketchup::Menu String name.\n"
              msg<< "Valid names are 1 of: 'Camera','Draw','Edit','File','Help','Plugins','Tools','View','Window'."
              stack =( caller(0).size < 2 ? caller(0) : caller(1) )
              raise(TypeError,msg,stack)
            else
              unless $menu_separator_list.include?(menuname)
                  UI.menu(menuname).add_separator
                  $menu_separator_list << menuname
                  return true
              end
            end
          else
            # caller has passed a menuobject, that is
            #   likely NOT one of the toplevel menus.
            unless menuobject.is_a?(Sketchup::Menu)
              stack =( caller(0).size < 2 ? caller(0) : caller(1) )
              raise(TypeError,"(2nd arg) Sketchup::Menu object expected.",stack)
            else
              unless $menu_separator_list.include?(menuname)
                  menuobject.add_separator
                  $menu_separator_list << menuname
                  return true
              end
            end
          end
          #
          return false
          #
      end #}
      #
      end # method definition check

    end #} PROXY CLASS

  end # module UI

#  ===========================================================================


  #{# RUN ONCE
  #
  unless file_loaded?(File.basename(__FILE__))

    file_loaded(File.basename(__FILE__))

  end
  #
  #}#
